****************************************
HTTPie: a CLI, cURL-like tool for humans
****************************************

.. image:: https://travis-ci.org/nano-db/NanoCube.svg?branch=modules-refactor
    :target: https://travis-ci.org/nano-db/NanoCube


.. image:: https://coveralls.io/repos/pmdartus/NanoCube/badge.png?branch=master
  :target: https://coveralls.io/r/pmdartus/NanoCube?branch=master


In-memory data structure for spatiotemporal data cubes. Project based on research made 
by `Information Visualization department <http://www.research.att.com/infovis>`_ at AT&T.

============
Installation
============

.. code-block:: bash

    $ sudo pip install nanodb


The package contains following command tools: ``nanodb`` and ``nanodb_server``.

**Warning:** Currently support python 2.7 only.
